function mix(in,out)
% mix		- Mass balance mixer module
% function mix(in,out)
% Simulates the behavior of a mixer.
% Argument   Gives
%    in    the indices of the inlet streams.
%   out    the index of the exit stream.
% mix mixes all the inlet
% streams to make the outlet stream.
% For additional help and picture, see PICMIX
% OKB, TYLC
% Example: >> mix(1:2,3) % mixes stream 1 and 2 to make 3
%                >> mix([2 5], 7) % mixes streams 2 and 5 to make 7
global ns
ns(out,:)=sum(ns(in,:));
